@@ -25,6 +25,7 @@ __all__ = (
     "GetChannelSchedulePaginatorName",
     "ListAlertsPaginatorName",
     "ListChannelsPaginatorName",
+    "ListLiveSourcesPaginatorName",
     "ListPlaybackConfigurationsPaginatorName",
     "ListPrefetchSchedulesPaginatorName",
     "ListSourceLocationsPaginatorName",
@@ -36,6 +37,7 @@ __all__ = (
     "PlaybackModeType",
     "RelativePositionType",
     "ScheduleEntryTypeType",
+    "TierType",
     "TypeType",
     "MediaTailorServiceName",
     "ServiceName",
@@ -50,6 +52,7 @@ ChannelStateType = Literal["RUNNING", "STOPPED"]
 GetChannelSchedulePaginatorName = Literal["get_channel_schedule"]
 ListAlertsPaginatorName = Literal["list_alerts"]
 ListChannelsPaginatorName = Literal["list_channels"]
+ListLiveSourcesPaginatorName = Literal["list_live_sources"]
 ListPlaybackConfigurationsPaginatorName = Literal["list_playback_configurations"]
 ListPrefetchSchedulesPaginatorName = Literal["list_prefetch_schedules"]
 ListSourceLocationsPaginatorName = Literal["list_source_locations"]
@@ -61,6 +64,7 @@ OriginManifestTypeType = Literal["MULTI_PERIOD", "SINGLE_PERIOD"]
 PlaybackModeType = Literal["LINEAR", "LOOP"]
 RelativePositionType = Literal["AFTER_PROGRAM", "BEFORE_PROGRAM"]
 ScheduleEntryTypeType = Literal["FILLER_SLATE", "PROGRAM"]
+TierType = Literal["BASIC", "STANDARD"]
 TypeType = Literal["DASH", "HLS"]
 MediaTailorServiceName = Literal["mediatailor"]
 ServiceName = Literal[
@@ -384,6 +388,7 @@ PaginatorName = Literal[
     "get_channel_schedule",
     "list_alerts",
     "list_channels",
+    "list_live_sources",
     "list_playback_configurations",
     "list_prefetch_schedules",
     "list_source_locations",
