@@ -23,6 +23,7 @@ from .literals import (
     PlaybackModeType,
     RelativePositionType,
     ScheduleEntryTypeType,
+    TierType,
     TypeType,
 )
 
@@ -50,6 +51,8 @@ __all__ = (
     "ConfigureLogsForPlaybackConfigurationResponseTypeDef",
     "CreateChannelRequestRequestTypeDef",
     "CreateChannelResponseTypeDef",
+    "CreateLiveSourceRequestRequestTypeDef",
+    "CreateLiveSourceResponseTypeDef",
     "CreatePrefetchScheduleRequestRequestTypeDef",
     "CreatePrefetchScheduleResponseTypeDef",
     "CreateProgramRequestRequestTypeDef",
@@ -64,6 +67,7 @@ __all__ = (
     "DefaultSegmentDeliveryConfigurationTypeDef",
     "DeleteChannelPolicyRequestRequestTypeDef",
     "DeleteChannelRequestRequestTypeDef",
+    "DeleteLiveSourceRequestRequestTypeDef",
     "DeletePlaybackConfigurationRequestRequestTypeDef",
     "DeletePrefetchScheduleRequestRequestTypeDef",
     "DeleteProgramRequestRequestTypeDef",
@@ -71,6 +75,8 @@ __all__ = (
     "DeleteVodSourceRequestRequestTypeDef",
     "DescribeChannelRequestRequestTypeDef",
     "DescribeChannelResponseTypeDef",
+    "DescribeLiveSourceRequestRequestTypeDef",
+    "DescribeLiveSourceResponseTypeDef",
     "DescribeProgramRequestRequestTypeDef",
     "DescribeProgramResponseTypeDef",
     "DescribeSourceLocationRequestRequestTypeDef",
@@ -96,6 +102,9 @@ __all__ = (
     "ListChannelsRequestListChannelsPaginateTypeDef",
     "ListChannelsRequestRequestTypeDef",
     "ListChannelsResponseTypeDef",
+    "ListLiveSourcesRequestListLiveSourcesPaginateTypeDef",
+    "ListLiveSourcesRequestRequestTypeDef",
+    "ListLiveSourcesResponseTypeDef",
     "ListPlaybackConfigurationsRequestListPlaybackConfigurationsPaginateTypeDef",
     "ListPlaybackConfigurationsRequestRequestTypeDef",
     "ListPlaybackConfigurationsResponseTypeDef",
@@ -111,6 +120,7 @@ __all__ = (
     "ListVodSourcesRequestRequestTypeDef",
     "ListVodSourcesResponseTypeDef",
     "LivePreRollConfigurationTypeDef",
+    "LiveSourceTypeDef",
     "LogConfigurationTypeDef",
     "ManifestProcessingRulesTypeDef",
     "PaginatorConfigTypeDef",
@@ -139,6 +149,8 @@ __all__ = (
     "UntagResourceRequestRequestTypeDef",
     "UpdateChannelRequestRequestTypeDef",
     "UpdateChannelResponseTypeDef",
+    "UpdateLiveSourceRequestRequestTypeDef",
+    "UpdateLiveSourceResponseTypeDef",
     "UpdateSourceLocationRequestRequestTypeDef",
     "UpdateSourceLocationResponseTypeDef",
     "UpdateVodSourceRequestRequestTypeDef",
@@ -228,6 +240,7 @@ _RequiredChannelTypeDef = TypedDict(
         "ChannelState": str,
         "Outputs": List["ResponseOutputItemTypeDef"],
         "PlaybackMode": str,
+        "Tier": str,
     },
 )
 _OptionalChannelTypeDef = TypedDict(
@@ -276,6 +289,7 @@ _OptionalCreateChannelRequestRequestTypeDef = TypedDict(
     {
         "FillerSlate": "SlateSourceTypeDef",
         "Tags": Mapping[str, str],
+        "Tier": TierType,
     },
     total=False,
 )
@@ -299,6 +313,44 @@ CreateChannelResponseTypeDef = TypedDict(
         "Outputs": List["ResponseOutputItemTypeDef"],
         "PlaybackMode": str,
         "Tags": Dict[str, str],
+        "Tier": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateLiveSourceRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateLiveSourceRequestRequestTypeDef",
+    {
+        "HttpPackageConfigurations": Sequence["HttpPackageConfigurationTypeDef"],
+        "LiveSourceName": str,
+        "SourceLocationName": str,
+    },
+)
+_OptionalCreateLiveSourceRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateLiveSourceRequestRequestTypeDef",
+    {
+        "Tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateLiveSourceRequestRequestTypeDef(
+    _RequiredCreateLiveSourceRequestRequestTypeDef, _OptionalCreateLiveSourceRequestRequestTypeDef
+):
+    pass
+
+
+CreateLiveSourceResponseTypeDef = TypedDict(
+    "CreateLiveSourceResponseTypeDef",
+    {
+        "Arn": str,
+        "CreationTime": datetime,
+        "HttpPackageConfigurations": List["HttpPackageConfigurationTypeDef"],
+        "LastModifiedTime": datetime,
+        "LiveSourceName": str,
+        "SourceLocationName": str,
+        "Tags": Dict[str, str],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -348,13 +400,14 @@ _RequiredCreateProgramRequestRequestTypeDef = TypedDict(
         "ProgramName": str,
         "ScheduleConfiguration": "ScheduleConfigurationTypeDef",
         "SourceLocationName": str,
-        "VodSourceName": str,
     },
 )
 _OptionalCreateProgramRequestRequestTypeDef = TypedDict(
     "_OptionalCreateProgramRequestRequestTypeDef",
     {
         "AdBreaks": Sequence["AdBreakTypeDef"],
+        "LiveSourceName": str,
+        "VodSourceName": str,
     },
     total=False,
 )
@@ -373,6 +426,7 @@ CreateProgramResponseTypeDef = TypedDict(
         "Arn": str,
         "ChannelName": str,
         "CreationTime": datetime,
+        "LiveSourceName": str,
         "ProgramName": str,
         "ScheduledStartTime": datetime,
         "SourceLocationName": str,
@@ -512,6 +566,14 @@ DeleteChannelRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeleteLiveSourceRequestRequestTypeDef = TypedDict(
+    "DeleteLiveSourceRequestRequestTypeDef",
+    {
+        "LiveSourceName": str,
+        "SourceLocationName": str,
+    },
+)
+
 DeletePlaybackConfigurationRequestRequestTypeDef = TypedDict(
     "DeletePlaybackConfigurationRequestRequestTypeDef",
     {
@@ -569,6 +631,29 @@ DescribeChannelResponseTypeDef = TypedDict(
         "Outputs": List["ResponseOutputItemTypeDef"],
         "PlaybackMode": str,
         "Tags": Dict[str, str],
+        "Tier": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeLiveSourceRequestRequestTypeDef = TypedDict(
+    "DescribeLiveSourceRequestRequestTypeDef",
+    {
+        "LiveSourceName": str,
+        "SourceLocationName": str,
+    },
+)
+
+DescribeLiveSourceResponseTypeDef = TypedDict(
+    "DescribeLiveSourceResponseTypeDef",
+    {
+        "Arn": str,
+        "CreationTime": datetime,
+        "HttpPackageConfigurations": List["HttpPackageConfigurationTypeDef"],
+        "LastModifiedTime": datetime,
+        "LiveSourceName": str,
+        "SourceLocationName": str,
+        "Tags": Dict[str, str],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -588,6 +673,7 @@ DescribeProgramResponseTypeDef = TypedDict(
         "Arn": str,
         "ChannelName": str,
         "CreationTime": datetime,
+        "LiveSourceName": str,
         "ProgramName": str,
         "ScheduledStartTime": datetime,
         "SourceLocationName": str,
@@ -877,6 +963,59 @@ ListChannelsResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListLiveSourcesRequestListLiveSourcesPaginateTypeDef = TypedDict(
+    "_RequiredListLiveSourcesRequestListLiveSourcesPaginateTypeDef",
+    {
+        "SourceLocationName": str,
+    },
+)
+_OptionalListLiveSourcesRequestListLiveSourcesPaginateTypeDef = TypedDict(
+    "_OptionalListLiveSourcesRequestListLiveSourcesPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListLiveSourcesRequestListLiveSourcesPaginateTypeDef(
+    _RequiredListLiveSourcesRequestListLiveSourcesPaginateTypeDef,
+    _OptionalListLiveSourcesRequestListLiveSourcesPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListLiveSourcesRequestRequestTypeDef = TypedDict(
+    "_RequiredListLiveSourcesRequestRequestTypeDef",
+    {
+        "SourceLocationName": str,
+    },
+)
+_OptionalListLiveSourcesRequestRequestTypeDef = TypedDict(
+    "_OptionalListLiveSourcesRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListLiveSourcesRequestRequestTypeDef(
+    _RequiredListLiveSourcesRequestRequestTypeDef, _OptionalListLiveSourcesRequestRequestTypeDef
+):
+    pass
+
+
+ListLiveSourcesResponseTypeDef = TypedDict(
+    "ListLiveSourcesResponseTypeDef",
+    {
+        "Items": List["LiveSourceTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListPlaybackConfigurationsRequestListPlaybackConfigurationsPaginateTypeDef = TypedDict(
     "ListPlaybackConfigurationsRequestListPlaybackConfigurationsPaginateTypeDef",
     {
@@ -1062,6 +1201,30 @@ LivePreRollConfigurationTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredLiveSourceTypeDef = TypedDict(
+    "_RequiredLiveSourceTypeDef",
+    {
+        "Arn": str,
+        "HttpPackageConfigurations": List["HttpPackageConfigurationTypeDef"],
+        "LiveSourceName": str,
+        "SourceLocationName": str,
+    },
+)
+_OptionalLiveSourceTypeDef = TypedDict(
+    "_OptionalLiveSourceTypeDef",
+    {
+        "CreationTime": datetime,
+        "LastModifiedTime": datetime,
+        "Tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class LiveSourceTypeDef(_RequiredLiveSourceTypeDef, _OptionalLiveSourceTypeDef):
+    pass
+
+
 LogConfigurationTypeDef = TypedDict(
     "LogConfigurationTypeDef",
     {
@@ -1318,7 +1481,6 @@ _RequiredScheduleEntryTypeDef = TypedDict(
         "ChannelName": str,
         "ProgramName": str,
         "SourceLocationName": str,
-        "VodSourceName": str,
     },
 )
 _OptionalScheduleEntryTypeDef = TypedDict(
@@ -1326,8 +1488,10 @@ _OptionalScheduleEntryTypeDef = TypedDict(
     {
         "ApproximateDurationSeconds": int,
         "ApproximateStartTime": datetime,
+        "LiveSourceName": str,
         "ScheduleAdBreaks": List["ScheduleAdBreakTypeDef"],
         "ScheduleEntryType": ScheduleEntryTypeType,
+        "VodSourceName": str,
     },
     total=False,
 )
@@ -1434,6 +1598,7 @@ _RequiredTransitionTypeDef = TypedDict(
 _OptionalTransitionTypeDef = TypedDict(
     "_OptionalTransitionTypeDef",
     {
+        "DurationMillis": int,
         "RelativeProgram": str,
         "ScheduledStartTimeMillis": int,
     },
@@ -1487,6 +1652,30 @@ UpdateChannelResponseTypeDef = TypedDict(
         "Outputs": List["ResponseOutputItemTypeDef"],
         "PlaybackMode": str,
         "Tags": Dict[str, str],
+        "Tier": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+UpdateLiveSourceRequestRequestTypeDef = TypedDict(
+    "UpdateLiveSourceRequestRequestTypeDef",
+    {
+        "HttpPackageConfigurations": Sequence["HttpPackageConfigurationTypeDef"],
+        "LiveSourceName": str,
+        "SourceLocationName": str,
+    },
+)
+
+UpdateLiveSourceResponseTypeDef = TypedDict(
+    "UpdateLiveSourceResponseTypeDef",
+    {
+        "Arn": str,
+        "CreationTime": datetime,
+        "HttpPackageConfigurations": List["HttpPackageConfigurationTypeDef"],
+        "LastModifiedTime": datetime,
+        "LiveSourceName": str,
+        "SourceLocationName": str,
+        "Tags": Dict[str, str],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
